@@ -8,8 +8,9 @@ function loadHistory() {
             ul = ul + '<a href="/zk?h=' + h + '" class="list-group-item list-group-item-action">' + h + '</a>';
         }
         if (ul.length > 0) {
+            $("#history").html("");
             let his = '<h4>History</h4><div class="list-group">' + ul + '</div>'
-            $(".container").append(his)
+            $("#history").append(his)
         }
     });
 }
@@ -26,7 +27,11 @@ function getTree() {
         url: "/tree?h="+$("#host").text(),
         dataType: "json"
     }).done(function(treeData){
-        $('#tree').text("");
-        $('#tree').bstreeview({data: JSON.stringify(treeData)});
+        if (treeData.status == 'success') {
+            $('#tree').text("");
+            $('#tree').bstreeview({data: JSON.stringify(treeData.data)});
+        } else {
+            $('#tree').text(treeData.message);
+        }
     })
 }
